import React, { FC, Ref } from 'react';
import { OverlayEvent, Placement } from 'rdk';
import { Modifiers } from 'popper.js';
export interface MenuProps {
    /**
     * Whether to append the menu to the body or not.
     */
    appendToBody?: boolean;
    /**
     * Autofocus the menu on open or not.
     */
    autofocus?: boolean;
    /**
     * The menu contents.
     */
    children: any;
    /**
     * CSS class applied to menu element.
     */
    className?: string;
    /**
     * Close the menu on click or not.
     */
    closeOnBodyClick: boolean;
    /**
     * Close the menu on escape.
     */
    closeOnEscape: boolean;
    /**
     * Popper placement type.
     */
    placement: Placement;
    /**
     * Reference element for the menu position.
     */
    reference?: any;
    /**
     * CSS Properties for the menu.
     */
    style?: React.CSSProperties;
    /**
     * Whether to show the menu or not.
     */
    open: boolean;
    /**
     * Max height of the menu.
     */
    maxHeight: string;
    /**
     * Popper.js Position modifiers.
     */
    modifiers?: Modifiers;
    /**
     * Whether the menu should be the same width as the reference element
     */
    autoWidth?: boolean;
    /**
     * Min width of the menu.
     */
    minWidth?: number;
    /**
     * Max width of the menu.
     */
    maxWidth?: number;
    /**
     * Menu was closed.
     */
    onClose: (event: OverlayEvent) => void;
    /**
     * Mouse enter event.
     */
    onMouseEnter: (event: any) => void;
    /**
     * Mouse leave event.
     */
    onMouseLeave: (event: any) => void;
}
export declare const Menu: FC<Partial<MenuProps & {
    ref?: Ref<HTMLDivElement>;
}>>;
